@@ -15,6 +15,7 @@ from typing import (
 
 from django.db import models
 from django.db.models import Prefetch
+from django.db.models.constants import LOOKUP_SEP
 from django.db.models.fields.reverse_related import (
     ManyToManyRel,
     ManyToOneRel,
@@ -120,6 +121,10 @@ def _get_model_hints(
         if not field:
             continue
 
+        # Do not optimize the field if the user asked not to
+        if getattr(field, "disable_optimization", False):
+            continue
+
         # Add annotations from the field if they exist
         field_store = getattr(field, "store", None)
         if field_store is not None:
@@ -145,7 +150,7 @@ def _get_model_hints(
                 # or else this might causa a refetch from the database
                 if isinstance(model_field, OneToOneRel):
                     remote_field = model_field.remote_field
-                    store.only.append(f"{path}__{resolve_model_field_name(remote_field)}")
+                    store.only.append(f"{path}{LOOKUP_SEP}{resolve_model_field_name(remote_field)}")
 
                 for f_type_def in get_possible_type_definitions(field.type):
                     f_model = model_field.related_model
@@ -159,7 +164,7 @@ def _get_model_hints(
                         level=level + 1,
                     )
                     model_cache.setdefault(f_model, []).append((level, f_store))
-                    store |= f_store.with_prefix(f"{path}__")
+                    store |= f_store.with_prefix(path)
             elif isinstance(model_field, (models.ManyToManyField, ManyToManyRel, ManyToOneRel)):
                 f_types = list(get_possible_type_definitions(field.type))
                 if len(f_types) > 1:
@@ -188,7 +193,12 @@ def _get_model_hints(
 
                     model_cache.setdefault(remote_model, []).append((level, f_store))
 
-                    f_qs = f_store.apply(remote_model.objects.all(), config=config)
+                    # We need to use _base_manager here instead of _default_manager because we
+                    # are getting related objects, and not querying it directly
+                    f_qs = f_store.apply(
+                        remote_model._base_manager.all(),  # type:ignore
+                        config=config,
+                    )
                     f_prefetch = Prefetch(path, queryset=f_qs)
                     f_prefetch._optimizer_sentinel = _sentinel  # type:ignore
                     store.prefetch_related.append(f_prefetch)
@@ -248,6 +258,9 @@ def optimize(
     if isinstance(qs, BaseManager):
         qs = cast(QuerySet[_M], qs.all())
 
+    # Small optimization to avoid optimizing queries twice
+    if getattr(qs, "_gql_optimized", False):
+        return qs
     # If the queryset already has cached results, just return it
     if qs._result_cache is not None:  # type:ignore
         return qs
@@ -265,30 +278,25 @@ def optimize(
         return qs
 
     for type_def in get_possible_type_definitions(strawberry_type):
-        selection = next(
-            (
-                s
-                for s in convert_selections(info, info.field_nodes)
-                if not isinstance(s, InlineFragment) and s.name == field_name
-            ),
-            None,
-        )
-        if not selection:
-            continue
+        for selection in convert_selections(info, info.field_nodes):
+            if isinstance(selection, InlineFragment) or selection.name != field_name:
+                continue
 
-        store |= _get_model_hints(
-            qs.model,
-            schema,
-            type_def,
-            selection,
-            config=config,
-        )
+            store |= _get_model_hints(
+                qs.model,
+                schema,
+                type_def,
+                selection,
+                config=config,
+            )
 
     # Nothing found do optimize, just skip this...
     if not store:
         return qs
 
-    return store.apply(qs, config=config)
+    qs = store.apply(qs, config=config)
+    qs._gql_optimized = True  # type:ignore
+    return qs
 
 
 @dataclasses.dataclass
@@ -371,7 +379,7 @@ class OptimizerStore:
         prefetch_related = []
         for p in self.prefetch_related:
             if isinstance(p, str):
-                prefetch_related.append(f"{prefix}{p}")
+                prefetch_related.append(f"{prefix}{LOOKUP_SEP}{p}")
             elif isinstance(p, Prefetch):
                 p.add_prefix(prefix)
                 prefetch_related.append(p)
@@ -379,8 +387,8 @@ class OptimizerStore:
                 raise AssertionError(f"Unexpected prefetch type {repr(p)}")
 
         return self.__class__(
-            only=[f"{prefix}{i}" for i in self.only],
-            select_related=[f"{prefix}{i}" for i in self.select_related],
+            only=[f"{prefix}{LOOKUP_SEP}{i}" for i in self.only],
+            select_related=[f"{prefix}{LOOKUP_SEP}{i}" for i in self.select_related],
             prefetch_related=prefetch_related,
         )
 
@@ -477,7 +485,7 @@ class DjangoOptimizerExtension(Extension):
         enable_only_optimization: bool = True,
         enable_select_related_optimization: bool = True,
         enable_prefetch_related_optimization: bool = True,
-        execution_context: ExecutionContext = None,
+        execution_context: Optional[ExecutionContext] = None,
     ):
         super().__init__(execution_context=execution_context)  # type:ignore
         self.config = OptimizerConfig(
@@ -522,4 +530,7 @@ class DjangoOptimizerExtension(Extension):
         *,
         store: Optional["OptimizerStore"] = None,
     ) -> QuerySet[_M]:
+        if not self.enabled.get():
+            return qs
+
         return optimize(qs, info, config=self.config, store=store)
